@@ -7,8 +7,9 @@ from typing import Callable
 from typing import Generator
 from typing import Iterator
 
-import execnet
 import pytest
+
+import execnet
 from execnet.gateway import Gateway
 from execnet.gateway_base import ExecModel
 from execnet.gateway_base import WorkerPool
@@ -161,8 +162,7 @@ def gw(
                 proxygw = group.makegateway("popen//id=%s" % pname)
             # assert group['proxygw'].remote_status().receiving
             gw = group.makegateway(
-                f"socket//id=socket//installvia={pname}"
-                f"//execmodel={execmodel.backend}"
+                f"socket//id=socket//installvia={pname}//execmodel={execmodel.backend}"
             )
             # TODO(typing): Clarify this assignment.
             gw.proxygw = proxygw  # type: ignore[attr-defined]
@@ -175,8 +175,7 @@ def gw(
         elif request.param == "proxy":
             group.makegateway("popen//id=proxy-transport")
             gw = group.makegateway(
-                "popen//via=proxy-transport//id=proxy"
-                "//execmodel=%s" % execmodel.backend
+                "popen//via=proxy-transport//id=proxy//execmodel=%s" % execmodel.backend
             )
         else:
             assert 0, f"unknown execmodel: {request.param}"
