@@ -1,11 +1,13 @@
 import os
-import sys
+from pathlib import Path
 
 import pytest
+
+from execnet.gateway_base import ExecModel
 from execnet.gateway_base import WorkerPool
 
 
-def test_execmodel(execmodel, tmp_path):
+def test_execmodel(execmodel: ExecModel, tmp_path: Path) -> None:
     assert execmodel.backend
     p = tmp_path / "somefile"
     p.write_text("content")
@@ -15,22 +17,22 @@ def test_execmodel(execmodel, tmp_path):
     f.close()
 
 
-def test_execmodel_basic_attrs(execmodel):
+def test_execmodel_basic_attrs(execmodel: ExecModel) -> None:
     m = execmodel
     assert callable(m.start)
     assert m.get_ident()
 
 
-def test_simple(pool):
+def test_simple(pool: WorkerPool) -> None:
     reply = pool.spawn(lambda: 42)
     assert reply.get() == 42
 
 
-def test_some(pool, execmodel):
+def test_some(pool: WorkerPool, execmodel: ExecModel) -> None:
     q = execmodel.queue.Queue()
     num = 4
 
-    def f(i):
+    def f(i: int) -> None:
         q.put(i)
         while q.qsize():
             execmodel.sleep(0.01)
@@ -45,10 +47,10 @@ def test_some(pool, execmodel):
     assert len(pool._running) == 0
 
 
-def test_running_semnatics(pool, execmodel):
+def test_running_semnatics(pool: WorkerPool, execmodel: ExecModel) -> None:
     q = execmodel.queue.Queue()
 
-    def first():
+    def first() -> None:
         q.get()
 
     reply = pool.spawn(first)
@@ -60,7 +62,7 @@ def test_running_semnatics(pool, execmodel):
     assert not reply.running
 
 
-def test_waitfinish_on_reply(pool):
+def test_waitfinish_on_reply(pool: WorkerPool) -> None:
     l = []
     reply = pool.spawn(lambda: l.append(1))
     reply.waitfinish()
@@ -71,20 +73,20 @@ def test_waitfinish_on_reply(pool):
 
 
 @pytest.mark.xfail(reason="WorkerPool does not implement limited size")
-def test_limited_size(execmodel):
-    pool = WorkerPool(execmodel, size=1)
+def test_limited_size(execmodel: ExecModel) -> None:
+    pool = WorkerPool(execmodel, size=1)  # type: ignore[call-arg]
     q = execmodel.queue.Queue()
     q2 = execmodel.queue.Queue()
     q3 = execmodel.queue.Queue()
 
-    def first():
+    def first() -> None:
         q.put(1)
         q2.get()
 
     pool.spawn(first)
     assert q.get() == 1
 
-    def second():
+    def second() -> None:
         q3.put(3)
 
     # we spawn a second pool to spawn the second function
@@ -98,8 +100,8 @@ def test_limited_size(execmodel):
     assert pool.waitall()
 
 
-def test_get(pool):
-    def f():
+def test_get(pool: WorkerPool) -> None:
+    def f() -> int:
         return 42
 
     reply = pool.spawn(f)
@@ -107,8 +109,8 @@ def test_get(pool):
     assert result == 42
 
 
-def test_get_timeout(execmodel, pool):
-    def f():
+def test_get_timeout(execmodel: ExecModel, pool: WorkerPool) -> None:
+    def f() -> int:
         execmodel.sleep(0.2)
         return 42
 
@@ -117,8 +119,8 @@ def test_get_timeout(execmodel, pool):
         reply.get(timeout=0.01)
 
 
-def test_get_excinfo(pool):
-    def f():
+def test_get_excinfo(pool: WorkerPool) -> None:
+    def f() -> None:
         raise ValueError("42")
 
     reply = pool.spawn(f)
@@ -128,10 +130,10 @@ def test_get_excinfo(pool):
         reply.get(1.0)
 
 
-def test_waitall_timeout(pool, execmodel):
+def test_waitall_timeout(pool: WorkerPool, execmodel: ExecModel) -> None:
     q = execmodel.queue.Queue()
 
-    def f():
+    def f() -> None:
         q.get()
 
     reply = pool.spawn(f)
@@ -142,10 +144,12 @@ def test_waitall_timeout(pool, execmodel):
 
 
 @pytest.mark.skipif(not hasattr(os, "dup"), reason="no os.dup")
-def test_pool_clean_shutdown(pool, capfd):
+def test_pool_clean_shutdown(
+    pool: WorkerPool, capfd: pytest.CaptureFixture[str]
+) -> None:
     q = pool.execmodel.queue.Queue()
 
-    def f():
+    def f() -> None:
         q.get()
 
     pool.spawn(f)
@@ -154,31 +158,31 @@ def test_pool_clean_shutdown(pool, capfd):
     with pytest.raises(ValueError):
         pool.spawn(f)
 
-    def wait_then_put():
+    def wait_then_put() -> None:
         pool.execmodel.sleep(0.1)
         q.put(1)
 
     pool.execmodel.start(wait_then_put)
     assert pool.waitall()
-    out, err = capfd.readouterr()
+    _out, err = capfd.readouterr()
     assert err == ""
 
 
-def test_primary_thread_integration(execmodel):
-    if execmodel.backend != "thread":
+def test_primary_thread_integration(execmodel: ExecModel) -> None:
+    if execmodel.backend not in ("thread", "main_thread_only"):
         with pytest.raises(ValueError):
             WorkerPool(execmodel=execmodel, hasprimary=True)
         return
     pool = WorkerPool(execmodel=execmodel, hasprimary=True)
     queue = execmodel.queue.Queue()
 
-    def do_integrate():
+    def do_integrate() -> None:
         queue.put(execmodel.get_ident())
         pool.integrate_as_primary_thread()
 
     execmodel.start(do_integrate)
 
-    def func():
+    def func() -> None:
         queue.put(execmodel.get_ident())
 
     pool.spawn(func)
@@ -188,13 +192,13 @@ def test_primary_thread_integration(execmodel):
     pool.terminate()
 
 
-def test_primary_thread_integration_shutdown(execmodel):
-    if execmodel.backend != "thread":
+def test_primary_thread_integration_shutdown(execmodel: ExecModel) -> None:
+    if execmodel.backend not in ("thread", "main_thread_only"):
         pytest.skip("can only run with threading")
     pool = WorkerPool(execmodel=execmodel, hasprimary=True)
     queue = execmodel.queue.Queue()
 
-    def do_integrate():
+    def do_integrate() -> None:
         queue.put(execmodel.get_ident())
         pool.integrate_as_primary_thread()
 
@@ -203,7 +207,7 @@ def test_primary_thread_integration_shutdown(execmodel):
 
     queue2 = execmodel.queue.Queue()
 
-    def get_two():
+    def get_two() -> None:
         queue.put(execmodel.get_ident())
         queue2.get()
 
